@@ -6,7 +6,7 @@ BEGIN {
   $App::colourhexdump::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $App::colourhexdump::VERSION = '0.01011317';
+  $App::colourhexdump::VERSION = '0.01011318';
 }
 
 # ABSTRACT: HexDump, but with character-class highlighting.
@@ -158,7 +158,7 @@ App::colourhexdump - HexDump, but with character-class highlighting.
 
 =head1 VERSION
 
-version 0.01011317
+version 0.01011318
 
 =head1 SYNOPSIS
 
@@ -178,9 +178,9 @@ It can be used like so
 
 If you are using an HTML-enabled POD viewer, you should see a screenshot of this in action:
 
-( Everyone else can visit L<https://github.com/kentfredric/App-colourhexdump/raw/images/Screenshot.png> )
+( Everyone else can visit L<http://kentfredric.github.io/App-colourhexdump/media/Screenshot.png> )
 
-=for html <center><img src="https://github.com/kentfredric/App-colourhexdump/raw/images/Screenshot.png" alt="Screenshot with explanation of colours" width="826" height="838"/></center>
+=for html <center><img src="http://kentfredric.github.io/App-colourhexdump/media/Screenshot.png" alt="Screenshot with explanation of colours" width="826" height="838"/></center>
 
 =head1 METHODS
 
